@@ -1,6 +1,6 @@
 from .leastsq_minimization import leastsq_minimization
 from .fidelity_maximization import fidelity_maximization
-from .visualize import (print_components, plot_components,
-                        inspect_leastsq_minimization, inspect_fidelity_maximization,
+from .visualize import (inspect_leastsq_minimization, inspect_fidelity_maximization,
                         plot_amplitude_scan, print_amplitude_scan)
+from .analysis import fidelity_loss
 from .common import make_heff_t, compose_ueff, heff_fidelity
